jenkins-bot has submitted this change. ( 
https://gerrit.wikimedia.org/r/c/pywikibot/core/+/1296031?usp=email )

Change subject: Update name for Brooke Vibber
......................................................................

Update name for Brooke Vibber

Update name for Brooke Vibber in AUTHORS.rst and other references

Change-Id: I81bf37f39648e41a84418d75070a0bf0644f29c9
---
M AUTHORS.rst
M tests/site_generators_tests.py
2 files changed, 4 insertions(+), 4 deletions(-)

Approvals:
  Matěj Suchánek: Looks good to me, approved
  jenkins-bot: Verified




diff --git a/AUTHORS.rst b/AUTHORS.rst
index 11c248d..ec4612e 100644
--- a/AUTHORS.rst
+++ b/AUTHORS.rst
@@ -50,7 +50,7 @@
     Betacommand
     Bináris
     borgo
-    Brion Vibber
+    Brooke Vibber
     Bryan Tong Minh

 C
diff --git a/tests/site_generators_tests.py b/tests/site_generators_tests.py
index f9a1bae..aa3f097 100755
--- a/tests/site_generators_tests.py
+++ b/tests/site_generators_tests.py
@@ -1227,13 +1227,13 @@
         mysite = self.get_site()
         start = '2008-10-08T03:05:07Z'
         for contrib in mysite.usercontribs(
-                userprefix='Brion',
+                userprefix='Brooke',
                 start=pywikibot.Timestamp.fromISOformat(start),
                 total=5, reverse=True):
             self.assertGreaterEqual(contrib['timestamp'], start)

         for contrib in mysite.usercontribs(
-                userprefix='Brion',
+                userprefix='Brooke',
                 end=pywikibot.Timestamp.fromISOformat('2008-10-09T04:06:08Z'),
                 total=5, reverse=True):
             self.assertLessEqual(contrib['timestamp'], '2008-10-09T04:06:08Z')
@@ -1527,7 +1527,7 @@

 class TestUserList(DefaultSiteTestCase):

     """Test usernames Jimbo Wales, Brion VIBBER and Tim Starling."""

     cached = True
@@ -1527,7 +1527,7 @@
 class TestUserList(DefaultSiteTestCase):

-    """Test usernames Jimbo Wales, Brion VIBBER and Tim Starling."""
+    """Test usernames Jimbo Wales, Brooke Vibber and Tim Starling."""

     cached = True


--
To view, visit 
https://gerrit.wikimedia.org/r/c/pywikibot/core/+/1296031?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.wikimedia.org/r/settings?usp=email

Gerrit-MessageType: merged
Gerrit-Project: pywikibot/core
Gerrit-Branch: master
Gerrit-Change-Id: I81bf37f39648e41a84418d75070a0bf0644f29c9
Gerrit-Change-Number: 1296031
Gerrit-PatchSet: 2
Gerrit-Owner: Bvibber <[email protected]>
Gerrit-Reviewer: Matěj Suchánek <[email protected]>
Gerrit-Reviewer: jenkins-bot
Gerrit-CC: Xqt <[email protected]>
_______________________________________________
Pywikibot-commits mailing list -- [email protected]
To unsubscribe send an email to [email protected]

Reply via email to